@@ -5,7 +5,7 @@ use warnings;
 use Aspect::Library        ();
 use Aspect::Advice::Before ();
 
-our $VERSION = '0.90';
+our $VERSION = '0.91';
 our @ISA     = 'Aspect::Library';
 
 sub get_advice {
@@ -14,6 +14,7 @@ sub get_advice {
 		lexical  => $self->lexical,
 		pointcut => $_[0],
 		code     => sub {
+			no warnings;
 			$DB::single = 1;
 		},
 	);
@@ -40,10 +41,6 @@ Aspect::Library::Breakpoint - A breakpoint aspect
   
   # The debugger will go into single statement mode for both methods
 
-=head1 SUPER
-
-L<Aspect::Modular>
-
 =head1 DESCRIPTION
 
 C<Aspect::Library::Breakpoint> is a reusable aspect for implementing
