@@ -8,7 +8,7 @@ use Aspect::Pointcut::And   ();
 use Aspect::Pointcut::Call  ();
 use Aspect::Pointcut::Cflow ();
 
-our $VERSION = '0.90';
+our $VERSION = '0.91';
 our @ISA     = 'Aspect::Modular';
 
 sub get_advice {
@@ -20,8 +20,7 @@ sub get_advice {
 			Aspect::Pointcut::Cflow->new( source => $_[0] ),
 		),
 		code => sub {
-			my $c = shift;
-			$c->append_param( $c->source->self );
+			$_->append_param( $_->source->self );
 		},
 	);
 }
@@ -58,10 +57,6 @@ Aspect::Library::Wormhole - A wormhole between call frames
   aspect Wormhole => 'A::a', 'C::c';
   print ref A->new->a; # with aspect, prints A
 
-=head1 SUPER
-
-L<Aspect::Modular>
-
 =head1 DESCRIPTION
 
 A reusable aspect for passing objects down a call flow, without adding
